#  tests for librttopo-1.1.0-h6a4060e_4 (this is a generated file);
print('===== testing package: librttopo-1.1.0-h6a4060e_4 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import sys
import ctypes

if sys.platform == 'win32':
    assert os.path.exists(os.path.join(sys.prefix, 'Library', 'lib', 'librttopo.lib'))
    path = os.path.join(sys.prefix, 'Library', 'bin', 'librttopo.dll')
    libfreexl = ctypes.CDLL(path)
elif sys.platform == 'darwin':
    # LD_LIBRARY_PATH not set on OS X or Linux.
    path = os.path.expandvars('$PREFIX/lib/librttopo.dylib')
    libfreexl = ctypes.CDLL(path)
elif sys.platform.startswith('linux'):
    path = os.path.expandvars('$PREFIX/lib/librttopo.so')
    libfreexl = ctypes.CDLL(path)
else:
    raise Exception('Cannot recognize platform {!r}'.format(sys.platform))
#  --- run_test.py (end) ---

print('===== librttopo-1.1.0-h6a4060e_4 OK =====');
